@@ -27,7 +27,8 @@ ROLE_EXCPETION = HTTPException(
     headers={"WWW-Authenticate": "Bearer"},
 )
 
-ACCESS_TOKEN_EXPIRE_MINUTES = 10
+# ambil dari setting config
+# ACCESS_TOKEN_EXPIRE_MINUTES = 10
 
 
 # =============================class=============================
@@ -54,6 +55,8 @@ class JwtToken(BaseModel):
     bankAreaId: ObjectIdStr = None
     bankBranchId: ObjectIdStr = None
     userId : ObjectIdStr = None
+    institutionCentralId: ObjectIdStr = None
+    institutionBranchId: ObjectIdStr = None
     # teamAreaId: ObjectIdStr = None
     role : str = None
     exp : int = 1000
@@ -64,7 +67,7 @@ async def mytoken(token: str = Depends(oauth2_scheme)):
 
 async def create_access_token(data: JwtToken, expires_delta: int):
     if expires_delta:
-        expire = datetime.utcnow() + timedelta(seconds=expires_delta)
+        expire = datetime.utcnow() + timedelta(minutes=expires_delta)
     else:
         expire = datetime.utcnow() + timedelta(minutes=15)
     data.exp = expire
@@ -86,6 +89,8 @@ async def get_current_user(security_scopes: SecurityScopes, token: str = Depends
         data_token.bankCentralId = payload.get("bankCentralId")
         data_token.bankAreaId = payload.get("bankAreaId")
         data_token.bankBranchId = payload.get("bankBranchId")
+        data_token.institutionCentralId = payload.get("institutionCentralId")
+        data_token.institutionBranchId = payload.get("institutionBranchId")
         # data_token.teamAreaId = payload.get("teamAreaId")
 
         data_token.role = payload.get("role")
@@ -112,13 +117,15 @@ async def create_refresh_token(response, token):
         data_token.bankCentralId = payload.get("bankCentralId")
         data_token.bankAreaId = payload.get("bankAreaId")
         data_token.bankBranchId = payload.get("bankBranchId")
+        data_token.institutionCentralId = payload.get("institutionCentralId")
+        data_token.institutionBranchId = payload.get("institutionBranchId")
         # data_token.teamAreaId = payload.get("teamAreaId")
         data_token.role = payload.get("role")
         # cek token sekarang masih on atau gak
         if datetime.utcfromtimestamp(payload.get("exp")) > datetime.utcnow():
             # cek username masih ada atau tidak
             # if(await GetUserOr404ByUsername(payload.get("username"))):
-            access_token = await create_access_token(data_token, ACCESS_TOKEN_EXPIRE_MINUTES)
+            access_token = await create_access_token(data_token, config.ACCESS_TOKEN_EXPIRE_MINUTES)
             # print(access_token)
             btoken = "Bearer " + str(access_token)
             response.headers["Authorization"] = btoken
